
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

##################################
Sample usage for grammartestsuites
##################################

.. include:: ../../nltk/test/grammartestsuites.doctest